require 'json'
require 'securerandom'

module KOAUtils
  module LeaderboardClient
    URL = Conf.env!('LEADERBOARD_URL')
    GAME_ID = Conf.env!('KOA_GAME_ID')

    def self.get_leaderboards(limit)
      Logger.measure_block("leaderboard-client.get-leaderboards") do
        response = KOAUtils::Request.make(
          type: :get,
          url: URL + "/boards",
          data: {limit: limit, game_id: GAME_ID}
        )
        if response.successful?
          JSON.parse(response.body)
        else
          {}
        end
      end
    end

    def self.get_user_scores(user_id)
      Logger.measure_block("leaderboard-client.get-user-scores") do
        response = KOAUtils::Request.make(
          type: :get,
          url: URL + "/user_scores",
          data: {game_id: GAME_ID, user_id: user_id}
        )
        if response.successful?
          user_scores = JSON.parse(response.body)
        end
      end
    end

    def self.add_score(user_id, score)
      Logger.measure_block("leaderboard-client.add-score") do
        KOAUtils::Request.make(
          type: :put,
          url: URL + "/score",
          data: {
            user_id: user_id,
            score: score,
            request_id: SecureRandom.uuid,
            game_id: GAME_ID
          },
          tries: 3,
          timeout: 5
        )
      end
    end

  end
end
