$stdout.sync = true
module KOAUtils
  class StringLogger
    def initialize
      @msgs = []
    end
    
    def puts(msg)
      @msgs << msg
    end
    
    def flush
      @msgs.length.times.map {@msgs.pop}
    end
  end
  
  module NullLogger
    def self.puts(*args)
      
    end
    
    def self.flush(*args)
      
    end
  end
  
  module Logger
    def self.appname
      @prefix ||= ENV['APP_NAME'].downcase if ENV['APP_NAME']
      if defined? ::Rails
        @prefix ||= Rails.application.class.parent_name.downcase+"."
      end
      @prefix ||= ""
    end
    
    def self.prefix(name)
      appname+name
    end
    
    def self.librato_log(type, name, val, data)
      name = prefix(name)
      data["#{type}##{name}"] = val
      log(data)
    end
    
    def self.out=(o)
      @out = o
    end
    
    def self.out
      @out || $stdout
    end
    
    def self.log(data)
      out.puts(stringify(data))
    end
    
    def self.measure_block(name, data = {})
      start = Time.now
      result = yield
      elapsed = (Time.now.to_f - start.to_f) * 1000
      measure(name, elapsed.round.to_s+"ms")
      result
    end
    
    def self.count(name, val, data = {})
      librato_log("count", name, val, data)
    end
    
    def self.measure(name, val, data = {})
      librato_log("measure", name, val, data)
    end
    
    def self.sample(name, val, data = {})
      librato_log("sample", name, val, data)
    end
    
    def self.stringify(data)
      data.reduce(out=String.new) do |s, tup|
        s << [tup.first, tup.last].join("=") << " "
      end
    end
  end
  
end