module KOAUtils
  if defined?(::Sequel)
      module ::Sequel
        class Database
          def log_yield(sql, args=nil)
            sql = "#{sql}; #{args.inspect}" if args
            t0 = Time.now
            begin
              yield
            rescue => e
              log_exception(e, sql)
              raise
            ensure
              t1 = Time.now
              log_duration(Integer((t1-t0)*1000), sql) unless e
            end
          end
  
          def log_duration(t, sql)
            Logger.measure("sequel-latency", t, source: action(sql))
          end
  
          def log_exception(e, sql)
            Logger.log(error: "sequel-exception", class: e.class)
          end
  
          def action(sql)
            sql[/(\w+){1}/].downcase
          end
        end
      end
    end
end
